==> artemis_cupps-0.0.63.tar.gz: lib/classes/Requests/aea_request_req.dart <==
import 'package:xml/xml.dart';

import '../classes.dart';

class AeaRequestRequest extends CuppsBase {
  final List<String> texts;
  final List<String> binaries;

  AeaRequestRequest(
      {required int messageID,
      String? xmlns,
      String? xsi,
      required this.texts,
      this.binaries = const []})
      : super(messageID: messageID, messageName: "aeaRequest");

  factory AeaRequestRequest.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String messageID = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "messageID")
        .value;
    List<XmlElement> messageElements =
        document.rootElement.findAllElements("aeaMessage").toList();
    List<XmlElement> textMessages = messageElements
        .where((element) =>
            element.childElements.any((ee) => ee.name.toString() == "aeaText"))
        .toList();
    List<XmlElement> binaryMessages = messageElements
        .where((element) => element.childElements
            .any((ee) => ee.name.toString() == "aeaBinary"))
        .toList();
    List<String> texts = textMessages.map((e) => e.text).toList();
    List<String> binaries = binaryMessages.map((e) => e.text).toList();

    return AeaRequestRequest(
        texts: texts, binaries: binaries, messageID: int.parse(messageID));
  }

  bool get isConfiguration => false;

  @override
  String toXML() {
    List<AeaMessage> textMessages = texts
        .map((e) => AeaMessage(
            aeaText: AeaText(data: e), aeaBinary: AeaBinary(data: "")))
        .toList();
    List<AeaMessage> binaryMessages = binaries
        .map((e) => AeaMessage(
            aeaText: AeaText(data: ""), aeaBinary: AeaBinary(data: e)))
        .toList();
    return '''<?xml version="1.0" encoding="utf-8"?>
    <cupps xmlns="$xmlns" messageID="$messageID" xmlns:xsi="#$xsi" messageName="$messageName">
    <aeaRequest>
    ${textMessages.map((e) => e.toXML()).join()}
    ${binaryMessages.map((e) => e.toXML()).join()}
    </aeaRequest>
    </cupps>''';
  }

  @override
  String toString() {
    return "$messageID : $messageName ";
  }
}

class AeaMessage {
  final AeaText aeaText;
  final AeaBinary aeaBinary;

  AeaMessage({required this.aeaText, required this.aeaBinary});
  factory AeaMessage.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    List<XmlElement> textElements =
        document.rootElement.findElements("aeaText").toList();
    List<XmlElement> binaryElements =
        document.rootElement.findElements("aeaBinary").toList();

    AeaText text = textElements.isEmpty
        ? AeaText(data: "")
        : textElements.map((e) => AeaText.fromXML(e.toXmlString())).first;
    AeaBinary binary = binaryElements.isEmpty
        ? AeaBinary(data: "")
        : binaryElements.map((e) => AeaBinary.fromXML(e.toXmlString())).first;

    return AeaMessage(aeaBinary: binary, aeaText: text);
  }

  String toXML() {
    return '''<aeaMessage>${aeaText.toXML()}${aeaBinary.toXML()}</aeaMessage>''';
  }
}

class AeaText {
  final String data;
  AeaText({required this.data});

  factory AeaText.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    XmlElement textElement = document.rootElement;
    String data = textElement.text;

    return AeaText(data: data);
  }

  String toXML() {
    if (data.isEmpty) return "";
    return '''<aeaText>${data.replaceAll("<", "&lt;").replaceAll(">", "&gt;")}</aeaText>''';
  }
}

class AeaBinary {
  final String data;
  AeaBinary({required this.data});

  factory AeaBinary.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    XmlElement textElement = document.rootElement;
    String data = textElement.text;

    return AeaBinary(data: data);
  }

  String toXML() {
    if (data.isEmpty) return "";
    return '''<aeaBinary>${data.replaceAll(" ", "&#32")}</aeaBinary>''';
  }
}

==> artemis_cupps-0.0.83.tar.gz: lib/classes/Requests/aea_request_req.dart <==
import 'package:xml/xml.dart';

import '../../utility/const.dart';
import '../classes.dart';

class AeaRequestRequest extends CuppsBase {
  final List<String> texts;
  final List<String> binaries;

  AeaRequestRequest(
      {required int messageID,
      String? xmlns,
      String? xsi,
      required this.texts,
      this.binaries = const []})
      : super(messageID: messageID, messageName: "aeaRequest");

  factory AeaRequestRequest.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String messageID = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "messageID")
        .value;
    List<XmlElement> messageElements =
        document.rootElement.findAllElements("aeaMessage").toList();
    List<XmlElement> textMessages = messageElements
        .where((element) =>
            element.childElements.any((ee) => ee.name.toString() == "aeaText"))
        .toList();
    List<XmlElement> binaryMessages = messageElements
        .where((element) => element.childElements
            .any((ee) => ee.name.toString() == "aeaBinary"))
        .toList();
    List<String> texts = textMessages.map((e) => e.text).toList();
    List<String> binaries = binaryMessages.map((e) => e.text).toList();

    return AeaRequestRequest(
        texts: texts, binaries: binaries, messageID: int.parse(messageID));
  }

  bool get isConfiguration => false;

  @override
  String toXML() {
    List<AeaMessage> textMessages = texts
        .map((e) => AeaMessage(
            aeaText: AeaText(data: e), aeaBinary: AeaBinary(data: "")))
        .toList();
    List<AeaMessage> binaryMessages = binaries
        .map((e) => AeaMessage(
            aeaText: AeaText(data: ""), aeaBinary: AeaBinary(data: e)))
        .toList();
    return '''<?xml version="1.0" encoding="utf-8"?>
    <cupps xmlns="$xmlns" messageID="$messageID" xmlns:xsi="#$xsi" messageName="$messageName">
    <aeaRequest>
    ${textMessages.map((e) => e.toXML()).join()}
    ${binaryMessages.map((e) => e.toXML()).join()}
    </aeaRequest>
    </cupps>''';
  }

  @override
  String toString() {
    return "$messageID : $messageName ";
  }
}

class AeaMessage {
  final AeaText aeaText;
  final AeaBinary aeaBinary;

  AeaMessage({required this.aeaText, required this.aeaBinary});
  factory AeaMessage.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    List<XmlElement> textElements =
        document.rootElement.findElements("aeaText").toList();
    List<XmlElement> binaryElements =
        document.rootElement.findElements("aeaBinary").toList();

    AeaText text = textElements.isEmpty
        ? AeaText(data: "")
        : textElements.map((e) => AeaText.fromXML(e.toXmlString())).first;
    AeaBinary binary = binaryElements.isEmpty
        ? AeaBinary(data: "")
        : binaryElements.map((e) => AeaBinary.fromXML(e.toXmlString())).first;

    return AeaMessage(aeaBinary: binary, aeaText: text);
  }

  String toXML() {
    return '''<aeaMessage>${aeaText.toXML()}${aeaBinary.toXML()}</aeaMessage>''';
  }
}

class AeaText {
  final String data;
  AeaText({required this.data});

  factory AeaText.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    XmlElement textElement = document.rootElement;
    String data = textElement.text;

    return AeaText(data: data);
  }

  String toXML() {
    if (data.isEmpty) return "";
    return '''<aeaText>${data.replaceAll("<", "&lt;").replaceAll(">", "&gt;").replaceAll(" ", artemisWhiteSpace).replaceAll("\n", artemisWhiteEnter)
    }</aeaText>''';
  }
}

class AeaBinary {
  final String data;
  AeaBinary({required this.data});

  factory AeaBinary.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    XmlElement textElement = document.rootElement;
    String data = textElement.text;

    return AeaBinary(data: data);
  }

  String toXML() {
    if (data.isEmpty) return "";
    return '''<aeaBinary>${data.replaceAll(" ", artemisWhiteSpace).replaceAll("\n", artemisWhiteEnter)}</aeaBinary>''';
  }
}
